@@ -1,4 +1,3 @@
-"""interface for base block visualizer"""
 from abc import abstractmethod
 
 from casymda.blocks.block_components.state import States
@@ -6,16 +5,14 @@ from casymda.blocks.entity import Entity
 
 
 class BlockVisualizer:
-    """visualizer called from the visualizable baseblock"""
+    """visualizer called from the visualizable_block"""
 
     @abstractmethod
     def animate_block(self, block, queuing_direction_x=None):
-        """animate_block"""
         raise NotImplementedError()
 
     @abstractmethod
     def change_block_state(self, block, state: States, new_value: bool):
-        """change_block_state"""
         raise NotImplementedError()
 
     @abstractmethod
