@@ -1,7 +1,7 @@
 """ entity """
 from typing import List, Optional
 
-from simpy import Environment, Resource
+from simpy import Environment, Resource, Process
 
 
 class Entity:
@@ -10,7 +10,7 @@ class Entity:
     def __init__(self, env: Environment, name: str):
         self.env = env
         self.name = name
-        self.current_process = None
+        self.current_process: Optional[Process] = None
 
         # requested resources, info needed for release
         self.seized_resources: List[Resource] = []
